@@ -619,7 +619,7 @@ bool Daemon::maybe_stats(bool send_ping)
 #ifdef HAVE_SYS_VFS_H
         struct statfs buf;
         int ret = statfs(envbasedir.c_str(), &buf);
-        if (!ret && buf.f_bavail < (max_kids + 1 - current_kids) * 4 * 1024 * 1024 / buf.f_bsize)
+        if (!ret && long(buf.f_bavail) < long(max_kids + 1 - current_kids) * 4 * 1024 * 1024 / buf.f_bsize)
             msg.load = 1000;
 #endif
 
@@ -777,6 +777,7 @@ bool Daemon::handle_transfer_env_done( Client *client )
     string current = client->outfile;
     client->outfile.clear();
     client->child_pid = -1;
+    assert( current_kids > 0 );
     current_kids--;
 
     log_error() << "installed_size: " << installed_size << endl;
@@ -1462,6 +1463,8 @@ int Daemon::working_loop()
             close_scheduler();
         }
     }
+    // never really reached
+    return 0;
 }
 
 int main( int argc, char ** argv )
@@ -1597,6 +1600,8 @@ int main( int argc, char ** argv )
         }
     }
 
+    umask(022);
+
     if ( !logfile.length() && detach)
         logfile = "/var/log/iceccd";
 
